mindroot.coreplugins.persona package
====================================

Submodules
----------

mindroot.coreplugins.persona.init\_persona module
-------------------------------------------------

.. automodule:: mindroot.coreplugins.persona.init_persona
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.persona.mod module
---------------------------------------

.. automodule:: mindroot.coreplugins.persona.mod
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: mindroot.coreplugins.persona
   :members:
   :show-inheritance:
   :undoc-members:
